
// plus4emu -- portable Commodore Plus/4 emulator
// Copyright (C) 2003-2008 Istvan Varga <istvanv@users.sourceforge.net>
// http://sourceforge.net/projects/plus4emu/
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "plus4emu.hpp"
#include "cpu.hpp"

namespace Plus4 {

  const unsigned char M7501::opcodeTable[4128] = {
    // 0x00: BRK
    CPU_OP_RD_TMP_NODEBUG,
    CPU_OP_PUSH_PCH,
    CPU_OP_PUSH_PCL,
    CPU_OP_BRK,
    CPU_OP_PUSH_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_PC_HL,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x01: ORA (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x02: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x03: SLO (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_ORA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x04: NOP nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x05: ORA nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x06: ASL nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x07: SLO nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_ORA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x08: PHP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_LD_TMP_SR,
    CPU_OP_PUSH_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x09: ORA #nn
    CPU_OP_RD_TMP,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x0A: ASL
    CPU_OP_LD_TMP_A,
    CPU_OP_ASL,
    CPU_OP_LD_A_TMP,
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x0B: ANC #nn
    CPU_OP_RD_TMP,
    CPU_OP_ANC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x0C: NOP nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x0D: ORA nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x0E: ASL nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x0F: SLO nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_ORA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x10: BPL nn
    CPU_OP_RD_L,
    CPU_OP_BPL,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x11: ORA (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x12: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x13: SLO (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_ORA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x14: NOP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x15: ORA nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x16: ASL nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x17: SLO nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_ORA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x18: CLC
    CPU_OP_CLC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x19: ORA nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x1A: NOP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x1B: SLO nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_ORA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x1C: NOP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x1D: ORA nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ORA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x1E: ASL nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x1F: SLO nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ASL,
    CPU_OP_ORA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x20: JSR nnnn
    CPU_OP_RD_L,
    CPU_OP_LD_DUMMY_MEM_SP,
    CPU_OP_PUSH_PCH,
    CPU_OP_PUSH_PCL,
    CPU_OP_RD_H,
    CPU_OP_LD_PC_HL,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x21: AND (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x22: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x23: RLA (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_AND,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x24: BIT nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_BIT,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x25: AND nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x26: ROL nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x27: RLA nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_AND,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x28: PLP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_LD_DUMMY_MEM_SP,
    CPU_OP_POP_TMP,
    CPU_OP_LD_SR_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x29: AND #nn
    CPU_OP_RD_TMP,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x2A: ROL
    CPU_OP_LD_TMP_A,
    CPU_OP_ROL,
    CPU_OP_LD_A_TMP,
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x2B: ANC #nn
    CPU_OP_RD_TMP,
    CPU_OP_ANC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x2C: BIT nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_BIT,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x2D: AND nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x2E: ROL nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x2F: RLA nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_AND,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x30: BMI nn
    CPU_OP_RD_L,
    CPU_OP_BMI,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x31: AND (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x32: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x33: RLA (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_AND,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x34: NOP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x35: AND nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x36: ROL nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x37: RLA nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_AND,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x38: SEC
    CPU_OP_SEC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x39: AND nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x3A: NOP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x3B: RLA nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_AND,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x3C: NOP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x3D: AND nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_AND,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x3E: ROL nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x3F: RLA nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROL,
    CPU_OP_AND,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x40: RTI
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_LD_DUMMY_MEM_SP,
    CPU_OP_POP_TMP,
    CPU_OP_LD_SR_TMP,
    CPU_OP_POP_PCL,
    CPU_OP_POP_PCH,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x41: EOR (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x42: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x43: SRE (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_EOR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x44: NOP nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x45: EOR nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x46: LSR nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x47: SRE nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_EOR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x48: PHA
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_LD_TMP_A,
    CPU_OP_PUSH_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x49: EOR #nn
    CPU_OP_RD_TMP,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x4A: LSR
    CPU_OP_LD_TMP_A,
    CPU_OP_LSR,
    CPU_OP_LD_A_TMP,
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x4B: ASR #nn
    CPU_OP_RD_TMP,
    CPU_OP_AND,
    CPU_OP_LD_TMP_A,
    CPU_OP_LSR,
    CPU_OP_LD_A_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x4C: JMP nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_PC_HL,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x4D: EOR nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x4E: LSR nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x4F: SRE nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_EOR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x50: BVC nn
    CPU_OP_RD_L,
    CPU_OP_BVC,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x51: EOR (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x52: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x53: SRE (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_EOR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x54: NOP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x55: EOR nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x56: LSR nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x57: SRE nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_EOR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x58: CLI
    CPU_OP_CLI,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x59: EOR nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x5A: NOP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x5B: SRE nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_EOR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x5C: NOP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x5D: EOR nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_EOR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x5E: LSR nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x5F: SRE nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_LSR,
    CPU_OP_EOR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x60: RTS
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_LD_DUMMY_MEM_SP,
    CPU_OP_POP_PCL,
    CPU_OP_POP_PCH,
    CPU_OP_RD_TMP_NODEBUG,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x61: ADC (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x62: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x63: RRA (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_ADC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x64: NOP nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x65: ADC nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x66: ROR nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x67: RRA nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_ADC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x68: PLA
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_LD_DUMMY_MEM_SP,
    CPU_OP_POP_TMP,
    CPU_OP_SET_NZ,
    CPU_OP_LD_A_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x69: ADC #nn
    CPU_OP_RD_TMP,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x6A: ROR
    CPU_OP_LD_TMP_A,
    CPU_OP_ROR,
    CPU_OP_LD_A_TMP,
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x6B: ARR #nn
    CPU_OP_RD_TMP,
    CPU_OP_ARR,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x6C: JMP (nnnn)
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_PC_HL,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x6D: ADC nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x6E: ROR nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x6F: RRA nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_ADC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x70: BVS nn
    CPU_OP_RD_L,
    CPU_OP_BVS,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x71: ADC (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x72: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x73: RRA (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_ADC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x74: NOP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x75: ADC nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x76: ROR nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x77: RRA nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_ADC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x78: SEI
    CPU_OP_SEI,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x79: ADC nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x7A: NOP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x7B: RRA nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_ADC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x7C: NOP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x7D: ADC nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_ADC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x7E: ROR nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x7F: RRA nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_ROR,
    CPU_OP_ADC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x80: NOP #nn
    CPU_OP_RD_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x81: STA (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_STA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x82: NOP #nn
    CPU_OP_RD_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x83: SAX (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_SAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x84: STY nn
    CPU_OP_RD_L,
    CPU_OP_STY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x85: STA nn
    CPU_OP_RD_L,
    CPU_OP_STA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x86: STX nn
    CPU_OP_RD_L,
    CPU_OP_STX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x87: SAX nn
    CPU_OP_RD_L,
    CPU_OP_SAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x88: DEY
    CPU_OP_DEY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x89: NOP #nn
    CPU_OP_RD_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x8A: TXA
    CPU_OP_TXA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x8B: ANE #nn
    CPU_OP_RD_TMP,
    CPU_OP_ANE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x8C: STY nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_STY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x8D: STA nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_STA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x8E: STX nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_STX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x8F: SAX nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_SAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x90: BCC nn
    CPU_OP_RD_L,
    CPU_OP_BCC,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x91: STA (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_STA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x92: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x93: SHA (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SHA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x94: STY nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_STY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x95: STA nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_STA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x96: STX nn, Y
    CPU_OP_RD_L,
    CPU_OP_ADDR_Y_ZEROPAGE,
    CPU_OP_STX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x97: SAX nn, Y
    CPU_OP_RD_L,
    CPU_OP_ADDR_Y_ZEROPAGE,
    CPU_OP_SAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x98: TYA
    CPU_OP_TYA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x99: STA nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_STA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x9A: TXS
    CPU_OP_TXS,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x9B: SHS nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SHS,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x9C: SHY nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SHY,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x9D: STA nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_STA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x9E: SHX nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SHX,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x9F: SHA nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SHA,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA0: LDY #nn
    CPU_OP_RD_TMP,
    CPU_OP_LDY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA1: LDA (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA2: LDX #nn
    CPU_OP_RD_TMP,
    CPU_OP_LDX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA3: LAX (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA4: LDY nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA5: LDA nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA6: LDX nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA7: LAX nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA8: TAY
    CPU_OP_TAY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xA9: LDA #nn
    CPU_OP_RD_TMP,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xAA: TAX
    CPU_OP_TAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xAB: LXA #nn
    CPU_OP_RD_TMP,
    CPU_OP_LXA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xAC: LDY nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xAD: LDA nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xAE: LDX nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xAF: LAX nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB0: BCS nn
    CPU_OP_RD_L,
    CPU_OP_BCS,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB1: LDA (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB2: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB3: LAX (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB4: LDY nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB5: LDA nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB6: LDX nn, Y
    CPU_OP_RD_L,
    CPU_OP_ADDR_Y_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB7: LAX nn, Y
    CPU_OP_RD_L,
    CPU_OP_ADDR_Y_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB8: CLV
    CPU_OP_CLV,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xB9: LDA nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xBA: TSX
    CPU_OP_TSX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xBB: LAS nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LAS,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xBC: LDY nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xBD: LDA nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDA,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xBE: LDX nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LDX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xBF: LAX nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LAX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC0: CPY #nn
    CPU_OP_RD_TMP,
    CPU_OP_CPY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC1: CMP (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC2: NOP #nn
    CPU_OP_RD_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC3: DCP (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_CMP,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC4: CPY nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CPY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC5: CMP nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC6: DEC nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC7: DCP nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_CMP,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC8: INY
    CPU_OP_INY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xC9: CMP #nn
    CPU_OP_RD_TMP,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xCA: DEX
    CPU_OP_DEX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xCB: SBX #nn
    CPU_OP_RD_TMP,
    CPU_OP_SBX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xCC: CPY nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CPY,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xCD: CMP nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xCE: DEC nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xCF: DCP nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_CMP,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD0: BNE nn
    CPU_OP_RD_L,
    CPU_OP_BNE,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD1: CMP (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD2: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD3: DCP (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_CMP,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD4: NOP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD5: CMP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD6: DEC nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD7: DCP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_CMP,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD8: CLD
    CPU_OP_CLD,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xD9: CMP nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xDA: NOP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xDB: DCP nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_CMP,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xDC: NOP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xDD: CMP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xDE: DEC nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xDF: DCP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_DEC,
    CPU_OP_CMP,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE0: CPX #nn
    CPU_OP_RD_TMP,
    CPU_OP_CPX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE1: SBC (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE2: NOP #nn
    CPU_OP_RD_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE3: ISB (nn, X)
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_SBC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE4: CPX nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CPX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE5: SBC nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE6: INC nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE7: ISB nn
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_SBC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE8: INX
    CPU_OP_INX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xE9: SBC #nn
    CPU_OP_RD_TMP,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xEA: NOP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xEB: SBC #nn
    CPU_OP_RD_TMP,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xEC: CPX nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_CPX,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xED: SBC nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xEE: INC nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xEF: ISB nnnn
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_SBC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF0: BEQ nn
    CPU_OP_RD_L,
    CPU_OP_BEQ,
    CPU_OP_JMP_RELATIVE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF1: SBC (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF2: ???
    CPU_OP_INVALID_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF3: ISB (nn), Y
    CPU_OP_RD_L,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_SBC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF4: NOP nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF5: SBC nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF6: INC nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF7: ISB nn, X
    CPU_OP_RD_L,
    CPU_OP_ADDR_X_ZEROPAGE,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_SBC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF8: SED
    CPU_OP_SED,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xF9: SBC nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xFA: NOP
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xFB: ISB nnnn, Y
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_Y_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_SBC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xFC: NOP nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xFD: SBC nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_SBC,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xFE: INC nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0xFF: ISB nnnn, X
    CPU_OP_RD_L,
    CPU_OP_RD_H,
    CPU_OP_ADDR_X_SLOW,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_MEM_TMP_NODEBUG,
    CPU_OP_INC,
    CPU_OP_SBC,
    CPU_OP_LD_MEM_TMP,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x100: INT
    CPU_OP_LD_DUMMY_MEM_PC,
    CPU_OP_LD_DUMMY_MEM_SP,
    CPU_OP_PUSH_PCH,
    CPU_OP_PUSH_PCL,
    CPU_OP_INTERRUPT,
    CPU_OP_PUSH_TMP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_PC_HL,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    // 0x101: RST
    CPU_OP_DEC_SP,
    CPU_OP_DEC_SP,
    CPU_OP_RESET,
    CPU_OP_DEC_SP,
    CPU_OP_LD_TMP_MEM,
    CPU_OP_LD_H_MEMP1_L_TMP,
    CPU_OP_LD_PC_HL,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE,
    CPU_OP_RD_OPCODE
  };

}       // namespace Plus4

