
// compressor utility for Commodore Plus/4 programs
// Copyright (C) 2007-2008 Istvan Varga <istvanv@users.sourceforge.net>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// The Plus/4 program files generated by this utility are not covered by the
// GNU General Public License, and can be used, modified, and distributed
// without any restrictions.

#ifndef P4COMPRESS_DECOMPRESS0_HPP
#define P4COMPRESS_DECOMPRESS0_HPP

#include "plus4emu.hpp"
#include "compress.hpp"
#include <vector>

namespace Plus4Compress {

  class Decompressor_M0 : public Decompressor {
   private:
    static const unsigned char  sfxModuleLibrary[1898];
    // main Huffman table (literal characters + match offset codes)
    unsigned int  *huffmanLimitTable0;
    unsigned int  *huffmanOffsetTable0;
    unsigned int  *huffmanDecodeTable0;
    // match length Huffman table
    unsigned int  *huffmanLimitTable1;
    unsigned int  *huffmanOffsetTable1;
    unsigned int  *huffmanDecodeTable1;
    bool          usingHuffTable0;
    bool          usingHuffTable1;
    unsigned char shiftRegister;
    int           shiftRegisterCnt;
    const unsigned char *inputBuffer;
    size_t        inputBufferSize;
    size_t        inputBufferPosition;
    unsigned int  prvMatchOffsets[4];
    unsigned int  prvMatchOffsetsPos;
    // --------
    unsigned int readBits(size_t nBits);
    unsigned int readLZMatchParameterBits(unsigned char n);
    unsigned int gammaDecode();
    unsigned int huffmanDecode(int huffTable);
    unsigned char readDeltaValue();
    unsigned int readMatchLength();
    void huffmanInit(int huffTable);
    bool decompressDataBlock(std::vector< unsigned char >& buf,
                             std::vector< bool >& bytesUsed);
   public:
    Decompressor_M0();
    virtual ~Decompressor_M0();
    virtual void decompressData(
        std::vector< std::vector< unsigned char > >& outBuf,
        const std::vector< unsigned char >& inBuf);
    // 'runAddr' can be the start address (0x0000 to 0xFFFF) of a machine code
    // program, or -1 for running a basic program, -2 to return to basic,
    // or -3 for monitor
    static void getSFXModule(std::vector< unsigned char >& outBuf,
                             int runAddr = -2, bool c16Mode = false,
                             bool fastSFXModule = false, bool noCleanup = false,
                             bool noROM = false, bool noCLI = false);
  };

}       // namespace Plus4Compress

#endif  // P4COMPRESS_DECOMPRESS0_HPP

